@@ -176,19 +176,19 @@ class TaskLoop:
         self._name = name
 
     def create(self):
+        print(VERSION)
         if VERSION.major==3 and VERSION.minor>=8:
-            task = asyncio.create_task(
+            task = self.loop.create_task(
                 coromask(
                     self.coro,
                     self.coro_args,
                     self.coro_kwargs,
-                    self.fargs),
-                name=self.name)
+                    self.fargs))
             task.add_done_callback(
                  functools.partial(self.renew, task, self.coro, self.fargs))
             return task
         if VERSION.major==3 and VERSION.minor==7:
-            task = asyncio.create_task(
+            task = self.loop.create_task(
                 coromask(
                     self.coro,
                     self.coro_args,
@@ -227,8 +227,7 @@ class TaskLoop:
                     if VERSION.major==3 and VERSION.minor>=8:
                         task = loop.create_task(
                             coromask(coro, result_args,
-                                     result_kwargs, fargs),
-                            name=self.name)
+                                     result_kwargs, fargs))
                     if VERSION.major==3 and VERSION.minor>=7:
                         task = loop.create_task(
                             coromask(coro, result_args,
@@ -242,8 +241,7 @@ class TaskLoop:
                     if VERSION.major==3 and VERSION.minor>=8:
                         task = loop.create_task(
                             coromask(pause, pause_args,
-                                     pause_kwargs, fargs),
-                            name=self.name)
+                                     pause_kwargs, fargs))
                     if VERSION.major==3 and VERSION.minor>=7:
                         task = loop.create_task(
                             coromask(pause, pause_args,
